@@ -36,13 +36,43 @@ if __name__ == '__main__':
 	gobject.threads_init() # also initializes the gdk threads
 	
 
-try:
-	import webkit
-except ImportError:
-	logging.info('Importing webkit failed')
-	webkit = None
-	
 from rednotebook.util import filesystem
+
+webkit = None
+
+def windows_webkit_import():
+	global webkit
+	
+	cwd = os.getcwd()
+	
+	if filesystem.main_is_frozen():
+		gtk_bin_dir = filesystem.app_dir
+		print gtk_bin_dir
+	else:
+		gtk_bin_dir = r'C:\GTK\bin'
+		
+	try:
+		# It seems the dlls are only found if we are in the bin dir
+		# during import
+		os.chdir(gtk_bin_dir)
+	except WindowsError:
+		logging.error('Changing dir to "%s" failed' % gtk_bin_dir)
+		return
+	
+	try:
+		import webkit
+	except ImportError:
+		logging.info('webkit not found. For a nicer preview install python-webkit or pywebkitgtk')
+	os.chdir(cwd)
+
+if sys.platform == 'win32':
+	windows_webkit_import()
+else:
+	try:
+		import webkit
+	except ImportError:
+		logging.info('webkit not found. For a nicer preview install python-webkit or pywebkitgtk')
+	
 	
 	
 def can_print_pdf():
@@ -57,7 +87,13 @@ def can_print_pdf():
 	
 	frame = printer._webview.get_main_frame()
 	
-	return hasattr(frame, 'print_full')
+	can_print_full = hasattr(frame, 'print_full')
+	
+	if not can_print_full:
+		msg = 'For direct PDF export, please install pywebkitgtk version 1.1.5 or later.'
+		logging.info(msg)
+	
+	return can_print_full
 	
 
 def print_pdf(html, filename):
@@ -85,7 +121,10 @@ class HtmlPrinter(object):
 		self._webview = webkit.WebView()
 		webkit_settings = self._webview.get_settings()
 		webkit_settings.set_property('enable-plugins', False)
-		self._webview.connect('load-error', self._load_error_cb)
+		try:
+			self._webview.connect('load-error', self._load_error_cb)
+		except TypeError, err:
+			logging.info(err)
 		self._paper_size = gtk.PaperSize(self.PAPER_SIZES[paper])
 		
 	def print_html(self, html, outfile):
@@ -137,6 +176,9 @@ class HtmlView(gtk.ScrolledWindow):
 		self.webview.connect('button-press-event', self.on_button_press)
 		self.nav_signal = self.webview.connect('navigation-requested', self.on_navigate)
 		
+		self.search_text = ''
+		self.webview.connect('load-finished', self.on_load_finished)
+		
 		self.show_all()
 		
 	def load_html(self, html):
@@ -145,8 +187,9 @@ class HtmlView(gtk.ScrolledWindow):
 		self.loading_html = False
 								
 	def get_html(self):
-		pass
-	
+		self.webview.execute_script("document.title=document.document_element.inner_h_t_m_l;")
+		return self.webview.get_main_frame().get_title()
+
 	def set_editable(self, editable):
 		self.webview.set_editable(editable)
 		
@@ -160,9 +203,16 @@ class HtmlView(gtk.ScrolledWindow):
 		self.webview.set_zoom_level(zoom)
 		
 	def highlight(self, string):
-		# Mark all occurences of "string", case-insensitive, no limit
-		self.webview.mark_text_matches(string, False, 0)
-		self.webview.set_highlight_text_matches(True)
+		# Not possible for all versions of pywebkitgtk
+		try:
+			# Remove results from last highlighting
+			self.webview.unmark_text_matches()
+				
+			# Mark all occurences of "string", case-insensitive, no limit
+			matches = self.webview.mark_text_matches(string, False, 0)
+			self.webview.set_highlight_text_matches(True)
+		except AttributeError, err:
+			logging.info(err)
 		
 	def on_populate_popup(self, webview, menu):
 		'''
@@ -193,9 +243,23 @@ class HtmlView(gtk.ScrolledWindow):
 		
 		# Stop processing that event
 		return True
+		
+	def on_load_finished(self, webview, frame):
+		'''
+		We use this method to highlight searched text.
+		Whenever new searched text is entered it is saved in the HtmlView
+		instance and highlighted, when the html is loaded.
+		
+		Trying to highlight text while the page is still being loaded
+		does not work.
+		'''
+		if self.search_text:
+			self.highlight(self.search_text)
+		else:
+			self.webview.set_highlight_text_matches(False)
 	
 if __name__ == '__main__':
-	logging.getLogger('').setLevel(logging.DEBUG)
+	logging.get_logger('').set_level(logging.DEBUG)
 	sys.path.insert(0, os.path.abspath("./../../"))
 	from rednotebook.util import markup
 	text = 'PDF export works 1 www.heise.de'
@@ -217,8 +281,14 @@ if __name__ == '__main__':
 	vbox.pack_start(button, False, False)
 	
 	html_view = HtmlView()
+	
+	def high(view, frame):
+		html_view.highlight("work")
+	html_view.webview.connect('load-finished', high)
+	
+	
 	html_view.load_html(html)
-	html_view.highlight("work")
+	
 	html_view.set_editable(True)
 	vbox.pack_start(html_view)
 	
